emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] 48/56: Remove incorrect uses of "modeline".


From: Luke Lee
Subject: [elpa] 48/56: Remove incorrect uses of "modeline".
Date: Thu, 28 Aug 2014 02:21:59 +0000

lukelee pushed a commit to branch master
in repository elpa.

commit 285534c36d82ed7412eb8e86107412f193d54679
Author: Chong Yidong <address@hidden>
Date:   Sat Jun 2 18:56:09 2012 +0800

    Remove incorrect uses of "modeline".
    
    * ansi-color.el (ansi-color-faces-vector): Change default faces.
    
    * cus-edit.el (mode-line):
    * dframe.el (dframe-mouse-hscroll):
    * emacs-lisp/re-builder.el:
    * emacs-lisp/easy-mmode.el (define-minor-mode):
    * frame.el (set-frame-name):
    * help.el (lookup-minor-mode-from-indicator):
    * net/rcirc.el (rcirc-activity-string, rcirc-short-buffer-name):
    * progmodes/cc-cmds.el (c-toggle-auto-newline)
    (c-toggle-hungry-state):
    * progmodes/antlr-mode.el (antlr-language-alist):
    * progmodes/idlw-shell.el (idlwave-shell-electric-stop-line-face):
    * progmodes/vhdl-mode.el (vhdl-mode):
    * progmodes/which-func.el (which-func, which-func-cleanup-function):
    * term/ns-win.el (ns-face-at-pos):
    * term/sup-mouse.el (sup-mouse-report):
    * textmodes/flyspell.el (flyspell-mode-line-string):
    * textmodes/ispell.el (ispell-highlight-face):
    * textmodes/reftex-global.el:
    * vc/vc-arch.el (vc-arch-mode-line-string):
    * vc/vc-cvs.el (vc-cvs-mode-line-string):
    * vc/vc-git.el (vc-git-mode-line-string):
    * vc/vc-hooks.el (vc-display-status)
    (vc-default-mode-line-string):
    * vc/vc-mtn.el (vc-mtn-mode-line-string): Doc fixes.
    
    * dired.el (dired-sort-set-mode-line): Rename from
    dired-sort-set-modeline.  All callers changed.
    
    * foldout.el (foldout-mode-line-string): Rename from
    foldout-modeline-string.  All callers changed.
    (foldout-update-mode-line): Rename from foldout-update-modeline.
    
    * strokes.el (strokes-lighter): Rename from
    strokes-modeline-string.
    
    * subr.el (redraw-modeline): Make into obsolete alias.
    
    * calendar/timeclock.el (timeclock-mode-line-display): Rename from
    timeclock-modeline-display.  Make old name an alias.
    (timeclock-update-mode-line): Likewise.  All callers changed.
    (timeclock-mode-line-display): No need to check before using
    add-hook.
    (timeclock-relative, timeclock-day-over-hook)
    (timeclock-use-elapsed, timeclock-mode-string)
    (timeclock-mode-line-display): Doc fix, "modeline" -> "mode line".
    
    * emulation/crisp.el (crisp-mode-mode-line-string): Rename from
    crisp-mode-modeline-string.
    
    * erc-track.el (erc-track, erc-track-faces-priority-list)
    (erc-track-faces-normal-list, erc-track-find-face)
    (erc-track-modified-channels): Fix modeline -> mode line in docs.
    
    * eshell/esh-mode.el (eshell-status-in-mode-line): Rename from
    eshell-status-in-modeline.
    
    * org-clock.el (org-clock-string-limit)
    (org-clock-modeline-total, org-clock-task-overrun-text)
    (org-clock-mode-line-entry): Doc fix, "modeline" -> "mode line".
    
    * play/solitaire.el (solitaire-build-mode-line): Rename from
    solitaire-build-modeline.  All callers changed.
    
    * play/zone.el (zone-hiding-mode-line): Rename from
    zone-hiding-modeline.  All callers changed.
    (zone): Remove unusued `modeline-hidden-level' property.
    
    * progmodes/xscheme.el (xscheme-mode-line-initialize): Rename from
    xscheme-modeline-initialize.  All callers changed.
    
    * textmodes/sgml-mode.el (html-face-tag-alist)
    (html-tag-face-alist): Use mode-line face instead of obsolete
    alias modeline.
---
 lisp/emulation/crisp.el |   15 +++++++++------
 1 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/lisp/emulation/crisp.el b/lisp/emulation/crisp.el
index 087a7e2..cfb8ed0 100644
--- a/lisp/emulation/crisp.el
+++ b/lisp/emulation/crisp.el
@@ -44,9 +44,9 @@
 ;; by default run `save-buffers-kill-emacs' instead of the command
 ;; `execute-extended-command'.
 
 ;; Finally, if you want to change the string displayed in the modeline
 ;; when this mode is in effect, override the definition of
 ;; `crisp-mode-modeline-string' in your .emacs.  The default value is
 ;; " *Crisp*" which may be a bit lengthy if you have a lot of things
 ;; being displayed there.
 
@@ -173,11 +173,14 @@
 All the bindings are done here instead of globally to try and be
 nice to the world.")
 
-(defcustom crisp-mode-modeline-string " *CRiSP*"
-  "String to display in the modeline when CRiSP emulation mode is enabled."
+(defcustom crisp-mode-mode-line-string " *CRiSP*"
+  "String to display in the mode line when CRiSP emulation mode is enabled."
   :type 'string
   :group 'crisp)
 
+(define-obsolete-variable-alias 'crisp-mode-modeline-string
+  'crisp-mode-mode-line-string "24.2")
+
 ;;;###autoload
 (defcustom crisp-mode nil
   "Track status of CRiSP emulation mode.
@@ -354,7 +357,7 @@ With a prefix argument ARG, enable CRiSP mode if ARG is 
positive,
 and disable it otherwise.  If called from Lisp, enable the mode
 if ARG is omitted or nil."
   :keymap crisp-mode-map
-  :lighter crisp-mode-modeline-string
+  :lighter crisp-mode-mode-line-string
   (when crisp-mode
     ;; Make menu entries show M-u or f14 in preference to C-x u.
     (put 'undo :advertised-binding
@@ -44,9 +44,9 @@
 ;; `execute-extended-command'.
 
-;; Finally, if you want to change the string displayed in the modeline
-;; when this mode is in effect, override the definition of
-;; `crisp-mode-modeline-string' in your .emacs.  The default value is
+;; Finally, if you want to change the string displayed in the mode
+;; line when this mode is in effect, override the definition of
+;; `crisp-mode-mode-line-string' in your .emacs.  The default value is
 ;; " *Crisp*" which may be a bit lengthy if you have a lot of things
 ;; being displayed there.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]